#ifndef GAME_H
#define GAME_H

#include <allegro.h>

#define PKEY_LEFT 0
#define PKEY_RIGHT 1
#define PKEY_JUMP 2
#define PKEY_SHOOT 3

#define VIEWPORT_X 0
#define VIEWPORT_Y 1
#define VIEWPORT_W 2
#define VIEWPORT_H 3

typedef struct
{
	unsigned char ani_x[5], ani_y[5];
	unsigned char max_ani, cur_ani;
	unsigned short type;
	unsigned short x, y;
	float var1, var2;
} OBJECT;

typedef struct
{
	unsigned char sprite;
	unsigned short x, y, tick;
	short health, lives;
	int keys[4];
	int score;
	int fallrate;
	int viewport[4];
	OBJECT fireball;
} PLAYER;

typedef struct
{
	unsigned char picx, picy;
	unsigned char type;
} TILE;

typedef struct
{
	unsigned int *tiles;
	OBJECT *objects;
	unsigned int nobjects;
	unsigned short w, h;
	unsigned short startx, starty;
	char *next_lvl;
} LEVEL;

extern TILE *tiles;
extern OBJECT *object_templates;
extern LEVEL *title_lvl;
extern PLAYER players[];
extern int nplayers;

extern int LoadTiles();
extern int LoadObjects();

extern LEVEL *LevelLoad(char *);
extern void LevelFree(LEVEL *);
extern BITMAP *LevelRender(LEVEL *);
extern void LevelRenderObjects(LEVEL *, BITMAP *);

extern int PlayGame(char *);
extern int RunLevel(LEVEL *);
extern void Storyline();

#define IS_SOLID(x) (tiles[x].type & 0x01)
#define POS_TO_TILE(x) ((x) >> 5)
#define GET_TILE(lvl, x, y) (lvl->tiles[(x) + (y) * lvl->w])

#endif
