#include <allegro.h>
#include <stdio.h>
#include "main.h"
#include "game.h"

BITMAP *graphics, *title_on, *title_off, *fadeout;
BITMAP *screenbuf;
int is_fullscreen, can_multi;
volatile int input_tick, game_tick;

void GameCleanup();
void Timer();

int main(int argc, char *argv[])
{
	PALETTE pal;
	FILE *fp;

	// We make sure _everything_ is zero'd. =) I'm paranoid like that.
	screenbuf = NULL;
	tiles = NULL;
	object_templates = NULL;
	title_lvl = NULL;
	graphics = title_off = title_on = fadeout = NULL;
	is_fullscreen = input_tick = game_tick = 0;
	nplayers = 0;
	can_multi = 0;

	allegro_init();
	atexit(GameCleanup);
	set_window_title("WizBang (TINS 2005 Entry)");

	// Have they unlocked multi player?
	fp = fopen("multi.key", "rb");
	if(fp != NULL)
	{
		fclose(fp);
		can_multi = 1;
	}

	set_color_depth(16);
	if(set_gfx_mode((is_fullscreen == 1 ? GFX_AUTODETECT_FULLSCREEN : GFX_AUTODETECT_WINDOWED), 640, 480, 0, 0) != 0)
	{
		allegro_message("Unable to set graphics mode.");
		return 1;
	}

	install_keyboard();
	install_timer();

	LOCK_VARIABLE(input_tick);
	LOCK_VARIABLE(game_tick);
	LOCK_FUNCTION(Timer);
	install_int(Timer, 100);

	if(LoadTiles())
	{
		allegro_message("Unable to load tile data.");
		return 1;
	}

	if(LoadObjects())
	{
		allegro_message("Unable to load object data.");
		return 1;
	}

	if((title_lvl = LevelLoad("title.lvl")) == NULL)
	{
		allegro_message("Unable to load level \"title.lvl\".");
		return 1;
	}

	graphics = load_bitmap("graphics.bmp", pal);
	title_off = load_bitmap("title_off.pcx", pal);
	title_on = load_bitmap("title_on.pcx", pal);
	fadeout = load_bitmap("fadeout.bmp", pal);
	if(!graphics || !title_off || !title_on || !fadeout)
	{
		allegro_message("Unable to load graphics.");
		return 1;
	}

	screenbuf = create_bitmap(640, 480);

	MainMenu();

	return 0;
}
END_OF_MAIN();

void GameCleanup()
{
	if(title_lvl) LevelFree(title_lvl);
	if(tiles) free(tiles);
	if(object_templates) free(object_templates);
	if(screenbuf) destroy_bitmap(screenbuf);
	if(graphics) destroy_bitmap(graphics);
	if(title_off) destroy_bitmap(title_off);
	if(title_on) destroy_bitmap(title_on);
	if(fadeout) destroy_bitmap(fadeout);
}

void Timer()
{
	if(input_tick < 0xFFFF) input_tick++;
	if(game_tick < 0xFFFF) game_tick++;
	if(players[0].tick < 0xFFFF) players[0].tick++;
	if(players[1].tick < 0xFFFF) players[1].tick++;
	if(players[2].tick < 0xFFFF) players[2].tick++;
	if(players[3].tick < 0xFFFF) players[3].tick++;
}
END_OF_FUNCTION(Timer);
